@@ -1,7 +1,6 @@
 import asyncio
 import logging
 import signal
-import sys
 
 from async_task_processor.exceptions import ATPException
 
@@ -30,9 +29,9 @@ class ATP:
         :return:
         """
         self.logger.info("canceling all pending tasks ...")
-        [task.cancel() for task in self.tasks]
+        for task in asyncio.Task.all_tasks():
+            task.cancel()
         self.logger.info("all tasks canceled, exit...")
-        sys.exit(0)
 
     def add_tasks(self, *tasks):
         """Add tasks
@@ -56,6 +55,9 @@ class ATP:
             self.loop.run_until_complete(asyncio.gather(*[task.coroutine_future for task in self.tasks]))
         except asyncio.CancelledError:
             pass
+        finally:
+            self.loop.stop()
+            self.loop.close()
 
     def filter(self, task_name):
         return list(filter(lambda x: x[1].name == task_name, enumerate(self.tasks)))
