@@ -39,11 +39,12 @@ class BaseProcessor:
         """You must override this method in processor. See task_processor.processors.TarantoolProcessor for example
 
         :param kwargs:
-        * *task_workers* (``list of instances of BaseTask``) -- You must make tasks in custom processor method, then call super
+        * *task_workers* (``list of instances of BaseTask``) -- You must make tasks in custom processor method,
+          then call super
          """
         if 'task_workers' not in kwargs or not isinstance(kwargs['task_workers'][0], BaseTask):
             raise ATPException(
-                "You must make tasks in your processor implementation first. 'tasks' must be in kwargs dict")
+                "you must make tasks in your processor implementation first. 'task_workers' must be in kwargs dict")
         self.__add_workers(kwargs['task_workers'])
 
     def __add_workers(self, task_workers):
@@ -65,32 +66,44 @@ class BaseProcessor:
         task.set_processor(self)
         return task
 
-    def stop(self, name, workers_count=1, leave_last=False):
-        """Stop task workers
+    def stop(self, task_name=None, task_id=None, workers_count=1, leave_last=False):
+        """Stop task workers. You can stop task or tasks by  name or id.
 
-        :param name: task name
-        :type name: str
+        :param task_name: task name
+        :type task_name: str
+        :param task_id: task id
+        :type task_name: str
         :param workers_count: number of workers to stop
         :type workers_count: int
-        :param leave_last: if true always leave one worker.
+        :param leave_last: if true always leave one worker. It works if only task_name argument is present
         :type leave_last: bool
         :return:
         """
         if not self.is_main_tread():
-            self._main_thread_queue.sync_q.put(
-                ('stop', dict(name=name, workers_count=workers_count, leave_last=leave_last)))
+            self._main_thread_queue.sync_q.put(('stop',
+                                                dict(task_name=task_name, task_id=task_id, workers_count=workers_count,
+                                                     leave_last=leave_last)))
             return
-        tasks = self.filter(name)
-        stop_tasks = tasks[:workers_count]
-        if leave_last and len(tasks) == workers_count:
-            stop_tasks = stop_tasks[:-1]
-        [task.remove() for task in stop_tasks]
-        [task.shutdown() for task in stop_tasks]
-        return stop_tasks
+        if task_id:
+            tasks4stop = self.filter_by_id(task_id)
+        else:
+            tasks4stop = self.filter_by_name(task_name)
+            tasks4stop = tasks4stop[:workers_count]
+            if leave_last and len(tasks4stop) == workers_count:
+                tasks4stop = tasks4stop[:-1]
+        if tasks4stop:
+            [task.remove() for task in tasks4stop]
+            [task.shutdown() for task in tasks4stop]
+        else:
+            self._atp.logger.warning('can\'t find task to stop')
+        return tasks4stop
 
-    def filter(self, task_name):
+    def filter_by_name(self, task_name):
         return list(filter(lambda x: x.name == task_name, self.tasks))
 
+    def filter_by_id(self, task_id):
+        return list(filter(lambda x: str(x.id) == task_id, self.tasks))
+
     @staticmethod
     def is_main_tread():
         return threading.get_ident() == threading.main_thread().ident
